@@ -19,7 +19,7 @@ with _dessert.rewrite_assertions_context():
 
 from checkpy.tests import test, failed, passed
 from checkpy.lib.basic import outputOf, getModule, getFunction
-from checkpy.lib.sandbox import only, include, exclude, require, download
+from checkpy.lib.sandbox import only, include, includeFromTests, exclude, require, download
 from checkpy.lib import static
 from checkpy.lib import monkeypatch
 from checkpy.lib.type import Type
@@ -39,6 +39,7 @@ __all__ = [
     "declarative",
     "only",
     "include",
+    "includeFromTests",
     "exclude",
     "require",
     "download",
@@ -46,4 +47,8 @@ __all__ = [
     "approx"
 ]
 
+# To be tested file
 file: _typing.Optional[_pathlib.Path] = None
+
+# Path to the tests directory
+testPath: _typing.Optional[_pathlib.Path] = None
\ No newline at end of file
